==> apache-cxf-3.6.8-src.zip: apache-cxf-3.6.8-src/rt/transports/http-netty/netty-server/src/main/java/org/apache/cxf/transport/http/netty/server/NettyHttpHandler.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.transport.http.netty.server;

import java.io.IOException;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.cxf.transport.http.HttpUrlUtil;

public class NettyHttpHandler {
    private String urlName;
    private boolean contextMatchExact;
    private NettyHttpDestination nettyHttpDestination;
    private ServletContext servletContext;

    public NettyHttpHandler(NettyHttpDestination nhd, boolean cmExact) {
        contextMatchExact = cmExact;
        nettyHttpDestination = nhd;
    }

    public void setServletContext(ServletContext sc) {
        servletContext = sc;
        if (nettyHttpDestination != null) {
            nettyHttpDestination.setServletContext(sc);
        }
    }

    public void setName(String name) {
        urlName = name;
    }

    public String getName() {
        return urlName;
    }


    public void handle(String target, HttpServletRequest request,
                       HttpServletResponse response) throws IOException, ServletException {
        if (contextMatchExact) {
            if (target.equals(urlName)) {
                nettyHttpDestination.doService(servletContext, request, response);
            }
        } else {
            if (target.equals(urlName) || HttpUrlUtil.checkContextPath(getName(), target)) {
                nettyHttpDestination.doService(servletContext, request, response);
            }
        }

    }

    public String getContextPath() {
        return servletContext.getContextPath();
    }

}

==> apache-cxf-4.0.7-src.zip: apache-cxf-4.0.7-src/rt/transports/http-netty/netty-server/src/main/java/org/apache/cxf/transport/http/netty/server/NettyHttpHandler.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.transport.http.netty.server;

import java.io.IOException;

import jakarta.servlet.ServletContext;
import jakarta.servlet.ServletException;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.apache.cxf.transport.http.HttpUrlUtil;

public class NettyHttpHandler {
    private String urlName;
    private boolean contextMatchExact;
    private NettyHttpDestination nettyHttpDestination;
    private ServletContext servletContext;

    public NettyHttpHandler(NettyHttpDestination nhd, boolean cmExact) {
        contextMatchExact = cmExact;
        nettyHttpDestination = nhd;
    }

    public void setServletContext(ServletContext sc) {
        servletContext = sc;
        if (nettyHttpDestination != null) {
            nettyHttpDestination.setServletContext(sc);
        }
    }

    public void setName(String name) {
        urlName = name;
    }

    public String getName() {
        return urlName;
    }


    public void handle(String target, HttpServletRequest request,
                       HttpServletResponse response) throws IOException, ServletException {
        if (contextMatchExact) {
            if (target.equals(urlName)) {
                nettyHttpDestination.doService(servletContext, request, response);
            }
        } else {
            if (target.equals(urlName) || HttpUrlUtil.checkContextPath(getName(), target)) {
                nettyHttpDestination.doService(servletContext, request, response);
            }
        }

    }

    public String getContextPath() {
        return servletContext.getContextPath();
    }

}
